;; Generated package description from php-fill.el  -*- no-byte-compile: t; lexical-binding:t -*-
(define-package "php-fill" "1.1.1" "Additional fill commands for PHP code editing" '((emacs "27.1")) :commit "73c1c8765a84b0318f2ba852c504e8251ced43ca" :authors '(("Ariel Del Valle Lozano" . "arielmazatlan@gmail.com")) :maintainer '("Ariel Del Valle Lozano" . "arielmazatlan@gmail.com") :keywords '("php" "languages" "tools" "convenience") :url "https://github.com/arielenter/php-fill.el")
